==> google-cloud-bigquery-logging-0.2.2.tar.gz: google-cloud-bigquery-logging-0.2.2/google/cloud/bigquery_logging_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from .types.audit_data import AuditData
from .types.audit_data import BigQueryAcl
from .types.audit_data import Dataset
from .types.audit_data import DatasetInfo
from .types.audit_data import DatasetInsertRequest
from .types.audit_data import DatasetInsertResponse
from .types.audit_data import DatasetListRequest
from .types.audit_data import DatasetName
from .types.audit_data import DatasetUpdateRequest
from .types.audit_data import DatasetUpdateResponse
from .types.audit_data import EncryptionInfo
from .types.audit_data import Job
from .types.audit_data import JobCompletedEvent
from .types.audit_data import JobConfiguration
from .types.audit_data import JobGetQueryResultsRequest
from .types.audit_data import JobGetQueryResultsResponse
from .types.audit_data import JobInsertRequest
from .types.audit_data import JobInsertResponse
from .types.audit_data import JobName
from .types.audit_data import JobQueryDoneResponse
from .types.audit_data import JobQueryRequest
from .types.audit_data import JobQueryResponse
from .types.audit_data import JobStatistics
from .types.audit_data import JobStatus
from .types.audit_data import Table
from .types.audit_data import TableDataListRequest
from .types.audit_data import TableDataReadEvent
from .types.audit_data import TableDefinition
from .types.audit_data import TableInfo
from .types.audit_data import TableInsertRequest
from .types.audit_data import TableInsertResponse
from .types.audit_data import TableName
from .types.audit_data import TableUpdateRequest
from .types.audit_data import TableUpdateResponse
from .types.audit_data import TableViewDefinition

__all__ = (
    "AuditData",
    "BigQueryAcl",
    "Dataset",
    "DatasetInfo",
    "DatasetInsertRequest",
    "DatasetInsertResponse",
    "DatasetListRequest",
    "DatasetName",
    "DatasetUpdateRequest",
    "DatasetUpdateResponse",
    "EncryptionInfo",
    "Job",
    "JobCompletedEvent",
    "JobConfiguration",
    "JobGetQueryResultsRequest",
    "JobGetQueryResultsResponse",
    "JobInsertRequest",
    "JobInsertResponse",
    "JobName",
    "JobQueryDoneResponse",
    "JobQueryRequest",
    "JobQueryResponse",
    "JobStatistics",
    "JobStatus",
    "Table",
    "TableDataListRequest",
    "TableDataReadEvent",
    "TableDefinition",
    "TableInfo",
    "TableInsertRequest",
    "TableInsertResponse",
    "TableName",
    "TableUpdateRequest",
    "TableUpdateResponse",
    "TableViewDefinition",
)

==> google-cloud-bigquery-logging-1.0.4.tar.gz: google-cloud-bigquery-logging-1.0.4/google/cloud/bigquery_logging_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from .types.audit_data import (
    AuditData,
    BigQueryAcl,
    Dataset,
    DatasetInfo,
    DatasetInsertRequest,
    DatasetInsertResponse,
    DatasetListRequest,
    DatasetName,
    DatasetUpdateRequest,
    DatasetUpdateResponse,
    EncryptionInfo,
    Job,
    JobCompletedEvent,
    JobConfiguration,
    JobGetQueryResultsRequest,
    JobGetQueryResultsResponse,
    JobInsertRequest,
    JobInsertResponse,
    JobName,
    JobQueryDoneResponse,
    JobQueryRequest,
    JobQueryResponse,
    JobStatistics,
    JobStatus,
    Table,
    TableDataListRequest,
    TableDataReadEvent,
    TableDefinition,
    TableInfo,
    TableInsertRequest,
    TableInsertResponse,
    TableName,
    TableUpdateRequest,
    TableUpdateResponse,
    TableViewDefinition,
)

__all__ = (
    "AuditData",
    "BigQueryAcl",
    "Dataset",
    "DatasetInfo",
    "DatasetInsertRequest",
    "DatasetInsertResponse",
    "DatasetListRequest",
    "DatasetName",
    "DatasetUpdateRequest",
    "DatasetUpdateResponse",
    "EncryptionInfo",
    "Job",
    "JobCompletedEvent",
    "JobConfiguration",
    "JobGetQueryResultsRequest",
    "JobGetQueryResultsResponse",
    "JobInsertRequest",
    "JobInsertResponse",
    "JobName",
    "JobQueryDoneResponse",
    "JobQueryRequest",
    "JobQueryResponse",
    "JobStatistics",
    "JobStatus",
    "Table",
    "TableDataListRequest",
    "TableDataReadEvent",
    "TableDefinition",
    "TableInfo",
    "TableInsertRequest",
    "TableInsertResponse",
    "TableName",
    "TableUpdateRequest",
    "TableUpdateResponse",
    "TableViewDefinition",
)
